Open Source Training Seminar FreePBX Paid Support

Ticket #3004 (closed Bugs: fixed)

Opened 3 weeks ago

Last modified 3 weeks ago

Spelling error in daynight

Reported by: mickecarlsson Assigned to:
Priority: minor Milestone: 2.5
Component: Day Night Mode Version: 2.5-branch
Keywords: Cc:
Confirmation: Confirmed SVN Revision (if applicable):
Backend Engine: All Backend Engine Version:

Description

--- page.daynight.org.php       2008-08-05 10:25:20.000000000 +0200
+++ page.daynight.php   2008-08-05 10:25:40.000000000 +0200
@@ -100,7 +100,7 @@
                                $dmode = ($ref['dmode'] == 'timeday') ? _("Forces to Nigh Mode") : _("Forces to Day Mode");
                                $timecondition_id = $ref['dest'];
                                $tcURL = $_SERVER['PHP_SELF'].'?'."display=timeconditions&itemid=$timecondition_id";
-                               $label = '<span><img width="16" height="16" border="0" title="'.sprintf(_("Linked to Time Condtion %s - %s"),$timecondition_id,$dmode).'" alt="" src="images/clock_link.png"/>&nbsp;'.sprintf(_("Linked to Time Condtion %s - %s"),$timecondition_id,$dmode).'</span>';
+                               $label = '<span><img width="16" height="16" border="0" title="'.sprintf(_("Linked to Time Condition %s - %s"),$timecondition_id,$dmode).'" alt="" src="images/clock_link.png"/>&nbsp;'.sprintf(_("Linked to Time Condtion %s - %s"),$timecondition_id,$dmode).'</span>';
 ?>
                                <a href="<?php echo $tcURL ?>"><?php echo $label; ?></a><br />
 <?php
@@ -161,7 +161,7 @@
        </tr>
        <tr>
                <td><a href="#" class="info"><?php echo _("Current Mode:")?>
-               <span><?php echo _("This will change the current state for this Day/Night Mode Control, or set the intial state when creating a new one.")?>
+               <span><?php echo _("This will change the current state for this Day/Night Mode Control, or set the initial state when creating a new one.")?>
                </span></a>
                </td>
                <td>

Change History

08/08/08 13:53:08 changed by p_lindheimer

  • confirmation changed from Unreviewed to Confirmed.
  • milestone changed from Cut Line to 2.5.

08/09/08 10:11:10 changed by mickecarlsson

  • status changed from new to closed.
  • resolution set to fixed.

(In [6300]) fixes #3004 spelling error

Donate



Support
Download
Develop
Forums
News
Documentation
Paid Support
About

Paid Ads
--- functions.inc.org.php       2008-08-05 10:24:07.000000000 +0200
+++ functions.inc.php   2008-08-05 10:25:09.000000000 +0200
@@ -428,7 +428,7 @@
 function daynight_add_timecondition($daynight_ref) {
        global $db;

        // We don't know what the new timecondtion id is yet so we will put a place holder and check it when the page reloads
        //
        daynight_edit_timecondition('add', $daynight_ref);
 }
@@ -442,7 +442,7 @@
                return null;
        }

-       // If we find anything, then we get the highest timecondtions_id which should be the last one inserted
+       // If we find anything, then we get the highest timeconditions_id which should be the last one inserted
        //
        if (! empty($res)) {

@@ -480,7 +480,7 @@
                        $html .= '<hr></h5></td></tr>';
                        $html .= '<tr>';
                        $html .= '<td><a href="#" class="info">';
-                       $html .= _("Associate with").'<span>'._("If a selection is made, this timecondtion will be associated with that featurecode and will allow this timecondtion to be direct overriden by that daynight mode featurecode").'.</span></a>:</td>';
+                       $html .= _("Associate with").'<span>'._("If a selection is made, this timecondition will be associated with that featurecode and will allow this timecondition to be direct overridden by that daynight mode featurecode").'.</span></a>:</td>';
                        $html .= '<td><select tabindex="'.++$tabindex.'" name="daynight_ref">';
                        $daynightcodes = daynight_list();
                        $current = daynight_get_timecondition($viewing_itemid);
@@ -508,11 +508,11 @@
        $daynight_ref = isset($request['daynight_ref']) ? $request['daynight_ref'] : '';

        // Do the un-natural act of checking to see if the last call was an add
-       // in which case we left a place holder for the timecondtions_id and we
+       // in which case we left a place holder for the timeconditions_id and we
        // need to go up-date it
        //
        // This is necessary because this process hook is called prior to the
-       // creation of the timecondition from the timecondtions module
+       // creation of the timecondition from the timeconditions module
        //
        if(!isset($request['action']) ) {
                daynight_checkadd_timecondition($daynight_ref);
@@ -531,7 +531,7 @@
        }
 }

 // Splice into the timecondtion dialplan and put an override if associated with a daynight mode code
 //
 function daynight_hookGet_config($engine) {
        global $ext;  // is this the best way to pass this?
@@ -428,7 +428,7 @@
        global $db;

-       // We don't know what the new timecondtion id is yet so we will put a place holder and check it when the page reloads
+       // We don't know what the new timecondition id is yet so we will put a place holder and check it when the page reloads
        //
        daynight_edit_timecondition('add', $daynight_ref);
@@ -531,7 +531,7 @@
 }

-// Splice into the timecondtion dialplan and put an override if associated with a daynight mode code
+// Splice into the timecondition dialplan and put an override if associated with a daynight mode code
 //
 function daynight_hookGet_config($engine) {